@@ -9,13 +9,13 @@
 #  _________________________________________________________________________
 
 
-import log_config as _config_
-import opt_config
+#import coopr.opt.base.log_config as _config_
+import coopr.opt.base.log_config
+import coopr.opt.base.opt_config
 
-from error import *
-from convert import *
-from solvers import *
-from results import *
-from problem import *
-from formats import *
-from symbol_map import *
+from coopr.opt.base.error import *
+from coopr.opt.base.convert import *
+from coopr.opt.base.solvers import *
+from coopr.opt.base.results import *
+from coopr.opt.base.problem import *
+from coopr.opt.base.formats import *
