@@ -10,8 +10,7 @@
 
 __all__ = [ 'IResultsReader', 'AbstractResultsReader', 'ReaderFactory' ]
 
-from pyutilib.component.core import *
-from pyutilib.component.config import *
+from coopr.core.plugin import *
 
 
 class IResultsReader(Interface):
@@ -19,13 +18,13 @@ class IResultsReader(Interface):
 
 ReaderFactory = CreatePluginFactory(IResultsReader)
 
-class AbstractResultsReader(ManagedPlugin):
+class AbstractResultsReader(Plugin):
     """Base class that can read optimization results."""
 
     implements(IResultsReader)
 
     def __init__(self, results_format):
-        ManagedPlugin.__init__(self)
+        Plugin.__init__(self)
         self.format=results_format
 
     def __call__(self, filename, res=None, suffixes=[]): #pragma:nocover
