@@ -8,15 +8,16 @@
 #  For more information, see the Coopr README.txt file.
 #  _________________________________________________________________________
 
-__all__ = ['IOptSolver', 'OptSolver', 'SolverFactory']
+__all__ = ['IOptSolver', 'OptSolver', 'PersistentSolver', 'SolverFactory', 'load_solvers']
 
+import re
 import os
 import sys
 import time
+import logging
 
 from pyutilib.enum import Enum
-from pyutilib.component.core import *
-from pyutilib.component.config import *
+from coopr.core.plugin import *
 import pyutilib.common
 import pyutilib.misc
 import pyutilib.services
@@ -27,6 +28,11 @@ import coopr.opt.base.results
 from coopr.opt.results import SolverResults, SolverStatus
 
 from six.moves import xrange
+from six import PY3
+using_py3 = PY3
+
+logger = logging.getLogger('coopr.opt')
+
 
 # The version string is first searched for trunk/Trunk, and if 
 # found a tuple of infinities is returned. Otherwise, the first
@@ -74,6 +80,75 @@ class IOptSolver(Interface):
     def set_options(self, istr):
         """Set the options in the optimizer from a string."""
 
+    def __bool__(self):
+        """Alias for self.available()"""
+
+
+class UnknownSolver(Plugin):
+    implements(IOptSolver)
+
+    def __init__(self, *args, **kwds):
+        #super(UnknownSolver,self).__init__(**kwds)
+        Plugin.__init__(self, **kwds)
+
+        #
+        # The 'type' is the class type of the solver instance
+        #
+        if "type" in kwds:
+            self.type = kwds["type"]
+        else:  #pragma:nocover
+            raise PluginError(
+                "Expected option 'type' for UnknownSolver constructor")
+
+        self.options = {}
+        self._args = args
+        self._kwds = kwds
+        self._options_str = []
+
+    #
+    # The following implement the base IOptSolver interface
+    #
+    
+    def available(self, exception_flag=True):
+        """Determine if this optimizer is available."""
+        return False
+
+    def warm_start_capable(self):
+        """ True is the solver can accept a warm-start solution."""
+        return False
+
+    def solve(self, *args, **kwds):
+        """Perform optimization and return an SolverResults object."""
+        self._solver_error('solve')
+
+    def reset(self):
+        """Reset the state of an optimizer"""
+        self._solver_error('reset')
+
+    def set_options(self, istr):
+        """Set the options in the optimizer from a string."""
+        self._options_str.append( istr )
+
+    def __bool__(self):
+        return self.available()
+
+    def __getattr__(self, attr):
+        self._solver_error(attr)
+
+    def _solver_error(self, method_name):
+        raise RuntimeError("""Attempting to use an unavailable solver.
+
+The SolverFactory was unable to create the solver "%s"
+and returned an UnknownSolver object.  This error is raised at the point 
+where the UnknownSolver object was used as if it were valid (by calling 
+method "%s").
+
+The original solver was created with the following parameters:
+\t""" % ( self.type, method_name )
++ "\n\t".join("%s: %s" % i for i in sorted(self._kwds.items()))
++ "\n\t_args: %s" % ( self._args, )
++ "\n\toptions: %s" % ( self.options, )
++ "\n\t_options_str: %s" % ( self._options_str, ) )
 
 SolverFactory = CreatePluginFactory(IOptSolver)
 def __solver_call__(self, _name=None, args=[], **kwds):
@@ -82,9 +157,9 @@ def __solver_call__(self, _name=None, args=[], **kwds):
     _name=str(_name)
     if ':' in _name:
         _name, subsolver = _name.split(':',1)
+        kwds['solver'] = subsolver
     elif 'solver' in kwds:
         subsolver = kwds['solver']
-        del kwds['solver']
     else:
         subsolver = None
     opt = None
@@ -96,19 +171,62 @@ def __solver_call__(self, _name=None, args=[], **kwds):
             mode = 'nl'
         pyutilib.services.register_executable(name=_name)
         if pyutilib.services.registered_executable(_name):
-            if mode == 'nl':
-                if "asl" not in IOptSolver._factory_cls:
-                    raise RuntimeError("The asl solver plugin was not registered as a valid solver plugin - cannot construct solver plugin with IO mode=nl")
-                opt = PluginFactory(IOptSolver._factory_cls['asl'], args, **kwds)
-            elif mode == 'os':
-                opt = PluginFactory(IOptSolver._factory_cls['_ossolver'], args, **kwds)
-            if not opt is None:
-                opt.set_options('solver='+_name)
-    if not opt is None and not subsolver is None:
-        opt.set_options('subsolver='+subsolver)
+            _implicit_solvers = {'nl': 'asl', 'os': '_ossolver' }
+            if mode in _implicit_solvers:
+                if _implicit_solvers[mode] not in IOptSolver._factory_cls:
+                    if 'coopr.environ' not in sys.modules:
+                        logger.warning(
+"""DEPRECATION WARNING: beginning in Coopr 4.0, plugins (including
+solvers and DataPortal clients) will not be automatically registered. To
+automatically register all plugins bundled with core Coopr, user scripts
+should include the line, "import coopr.environ".""" )
+                        import coopr.environ
+                        return __solver_call__(self, _name, args, **kwds)
+                    raise RuntimeError(
+                        "The %s solver plugin was not registered as a valid "
+                        "solver plugin - cannot construct solver plugin with "
+                        "IO mode=%s" % (_implicit_solvers[mode], mode) )
+                opt = PluginFactory(
+                    IOptSolver._factory_cls[_implicit_solvers[mode]], 
+                    args, **kwds )
+                if opt is not None:
+                    opt.set_options('solver='+_name)
+    if opt is not None and subsolver is not None:
+        opt.set_options('solver='+subsolver)
+    if opt is None:
+        if 'coopr.environ' not in sys.modules:
+            logger.warning(
+"""DEPRECATION WARNING: beginning in Coopr 4.0, plugins (including
+solvers and DataPortal clients) will not be automatically registered. To
+automatically register all plugins bundled with core Coopr, user scripts
+should include the line, "import coopr.environ".""" )
+            import coopr.environ
+            return __solver_call__(self, _name, args, **kwds)
+        opt = UnknownSolver( type=_name, *args, **kwds )
+        opt.name = _name
     return opt
 pyutilib.misc.add_method(SolverFactory, __solver_call__, name='__call__')
 
+#
+# TODO: It is impossible to load CBC with NL file-io using this function,
+#       i.e., SolverFactory("cbc", solver_io='nl'),
+#       this is NOT asl:cbc (same with PICO)
+# WEH:  Why is there a distinction between SolverFactory('asl:cbc') and SolverFactory('cbc', solver_io='nl')???   This is bad.
+#
+def load_solvers(*args):
+    ans = {}
+    for arg in args:
+        if not isinstance(arg,tuple):
+            name = arg
+            arg = (arg,)
+        else:
+            name = arg[0]
+        opt = SolverFactory(*arg)
+        if not opt is None and not opt.available():
+            opt = None
+        ans[name] = opt
+    return ans
+
 
 class OptSolver(Plugin):
     """A generic optimization solver"""
@@ -187,6 +305,9 @@ class OptSolver(Plugin):
         # We define no capabilities for the generic solver; base classes must override this
         self._capabilities = pyutilib.misc.Options()
 
+    def __bool__(self):
+        return self.available()
+
     def version(self):
         """
         Returns a tuple describing the solver executable version.
@@ -361,7 +482,12 @@ class OptSolver(Plugin):
         self.available()
 
         (self._problem_files,self._problem_format,self._symbol_map) = self._convert_problem(args, self._problem_format, self._valid_problem_formats)
-        if type(self._problem_files) in (list,tuple) and not isinstance(self._problem_files[0], basestring):
+        if using_py3:
+            compare_type = str
+        else:
+            compare_type = basestring
+
+        if type(self._problem_files) in (list,tuple) and not isinstance(self._problem_files[0], compare_type):
             self._problem_files = self._problem_files[0]._problem_files()
         if self._results_format is None:
             self._results_format= self._default_results_format(self._problem_format)
@@ -458,3 +584,10 @@ class OptSolver(Plugin):
         else:
             self._callback[name] = callback_fn
 
+class PersistentSolver(OptSolver):
+
+    def __init__(self, **kwds):
+        """ Constructor """
+
+        PersistentSolver.__init__(self,**kwds)
+
