@@ -8,12 +8,6 @@
 #  For more information, see the Coopr README.txt file.
 #  _________________________________________________________________________
 
-import pyutilib.component.core
-
-pyutilib.component.core.PluginGlobals.push_env( "coopr.opt" )
-
 from coopr.opt.parallel.async_solver import *
 import coopr.opt.parallel.manager
 import coopr.opt.parallel.local
-
-pyutilib.component.core.PluginGlobals.pop_env()
