@@ -8,4 +8,4 @@
 #  For more information, see the Coopr README.txt file.
 #  _________________________________________________________________________
 
-from ampl import *
+from coopr.opt.problem.ampl import *
