@@ -280,7 +280,7 @@ class ListContainer(object):
 #
 class MapContainer(dict):
 
-    def __del__(self):
+    def X__del__(self):
         self._order = []
         self.__dict__ = {}
 
