@@ -6,7 +6,10 @@
 import sys
 from pyutilib.misc import Options
 from coopr.opt import SolverResults
+from coopr.core import coopr_command
 
+
+@coopr_command('results_schema', "Print the predefined schema for a results object")
 def main():
     if len(sys.argv) > 1:
         print("results_schema  - Print the predefined schema in a SolverResults object")
