@@ -29,7 +29,7 @@ class ILMLicensedSystemCallSolver(SystemCallSolver):
         """ Constructor """
         coopr.opt.solver.shellcmd.SystemCallSolver.__init__(self, **kwds)
 
-    def available(self, exception_flag=True):
+    def available(self, exception_flag=False):
         """ True if the solver is available """
         if self._assert_available:
             return True
