@@ -12,12 +12,14 @@ cooprdir += os.sep
 currdir = dirname(abspath(__file__))+os.sep
 
 from nose.tools import nottest
-import coopr.opt.blackbox
 import xml
-from coopr.opt import ResultsFormat, ProblemFormat
+from coopr.opt import ResultsFormat, ProblemFormat, SolverFactory
 import pyutilib.services
 import pyutilib.th as unittest
+import coopr.opt.blackbox
+import coopr.environ
 
+old_tempdir = pyutilib.services.TempfileManager.tempdir
 
 class TestProblem1(coopr.opt.blackbox.MixedIntOptProblem):
 
@@ -105,6 +107,7 @@ class TestDakotaMain(unittest.TestCase):
 
     def tearDown(self):
         pyutilib.services.TempfileManager.clear_tempfiles()
+        pyutilib.services.TempfileManager.tempdir = old_tempdir
 
     def test_main(self):
         self.problem.main(['test_main', currdir+'request1.din', currdir+'results1.out'], format='dakota')
@@ -119,7 +122,7 @@ class TestColinMain(unittest.TestCase):
 
     def do_setup(self,flag):
         pyutilib.services.TempfileManager.tempdir = currdir
-        self.ps = coopr.plugins.solvers.ps.PatternSearch()
+        self.ps = SolverFactory('ps')
         self.problem=TestProblem1()
         self.rproblem=RealProblem3()
 
@@ -164,7 +167,7 @@ class TestOptProblem(unittest.TestCase):
 
     def do_setup(self,flag):
         pyutilib.services.TempfileManager.tempdir = currdir
-        self.ps = coopr.plugins.solvers.ps.PatternSearch()
+        self.ps = SolverFactory('ps')
         self.problem=TestProblem1()
         self.rproblem=RealProblem3()
 
